@@ -1,8 +1,8 @@
 // This file is part of fityk program. Copyright 2001-2013 Marcin Wojdyr
 // Licence: GNU General Public License ver. 2+
 
-#ifndef FITYK__GNUPLOT__H__
-#define FITYK__GNUPLOT__H__
+#ifndef FITYK_GNUPLOT_H_
+#define FITYK_GNUPLOT_H_
 
 #include <stdio.h>
 
