@@ -109,7 +109,7 @@ string op2str(int op)
         OP_(FUNC) OP_(SUM_F) OP_(SUM_Z)
         OP_(NUMAREA) OP_(FINDX) OP_(FIND_EXTR)
         OP_(TILDE)
-        OP_(DATASET) OP_(DT_SUM_SAME_X) OP_(DT_AVG_SAME_X) OP_(DT_SHIRLEY_BG)
+        OP_(DATASET) OP_(DT_SUM_SAME_X) OP_(DT_AVG_SAME_X) OP_(DT_SHIRLEY_BG) OP_(DT_SNIP_BG)
         OP_(OPEN_ROUND)  OP_(OPEN_SQUARE)
     }
     return S(op); // unreachable (if all OPs are listed above)
@@ -633,6 +633,11 @@ void run_func_op(const vector<realt>& numbers, vector<int>::const_iterator &i,
 
         case OP_TILDE:
             // used for default values in Runner::make_func_from_template()
+            // compare with ModelManager::eval_tilde()
+            assert(*(i+1) == OP_NUMBER);
+            STACK_OFFSET_CHANGE(+1);
+            *stackPtr = numbers[*(i+2)];
+            i += (*(i+3) == OP_TILDE ? 3 : 6);
             break;
 
         default:
