@@ -8,11 +8,6 @@
 #include <wx/filesys.h>
 #include <wx/tooltip.h>
 
-#ifdef __WXGTK3__
-#error "Not everything is working with wxGTK3. Use default wxGTK instead, " \
-       "based on GTK+2. If you want to test it, just remove this #error."
-#endif
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <vector>
@@ -39,6 +34,13 @@ using namespace std;
 using fityk::UserInterface;
 using fityk::range_vector;
 
+#ifdef HELP_DIR
+// We don't pass HELP_DIR directly to wxString as a workaround for a problem
+// with Conda builds. wxString uses the system wchar_t by default
+// and Conda overlooks wide strings when replacing prefixes.
+static const char* kHelpDir = HELP_DIR;
+#endif
+
 IMPLEMENT_APP(FApp)
 
 
@@ -155,7 +157,7 @@ UserInterface::Status gui_exec_command(const string& s)
     try {
         r = ftk->ui()->execute_line(s);
     }
-    catch(fityk::ExitRequestedException) {
+    catch(const fityk::ExitRequestedException&) {
         frame->Close(true);
         return UserInterface::kStatusOk;
     }
@@ -164,12 +166,6 @@ UserInterface::Status gui_exec_command(const string& s)
 }
 //-------------------------------------------------------------------------
 
-static
-void interrupt_handler (int /*signum*/)
-{
-    fityk::user_interrupt = 1;  // set flag to stop computations
-}
-
 static
 void write_white_config(wxConfigBase *w)
 {
@@ -203,21 +199,16 @@ FApp::FApp()
 
 bool FApp::OnInit(void)
 {
-#ifndef _WIN32
-    // setting Ctrl-C handler
-    if (signal (SIGINT, interrupt_handler) == SIG_IGN)
-        signal (SIGINT, SIG_IGN);
-#endif //_WIN32
-
-    SetAppName(wxT("fityk"));
+    fityk::interrupt_computations_on_sigint();
+    SetAppName("fityk");
 
     // if options can be parsed
     wxCmdLineParser cmdLineParser(cmdLineDesc, argc, argv);
     if (cmdLineParser.Parse(false) != 0) {
         cmdLineParser.Usage();
         return false; //false = exit the application
-    } else if (cmdLineParser.Found(wxT("V"))) {
-        wxMessageOutput::Get()->Printf(wxT("fityk version %s\n"), wxT(VERSION));
+    } else if (cmdLineParser.Found("V")) {
+        wxMessageOutput::Get()->Printf("fityk version %s\n", VERSION);
         return false; //false = exit the application
     } else if (cmdLineParser.Found("full-version")) {
         wxMessageOutput::Get()->Printf("fityk version %s\n%s\n%s\n", VERSION,
@@ -259,7 +250,7 @@ bool FApp::OnInit(void)
     wxConfig::Set(config);
 
     // directory for configs
-    config_dir = fityk_dir + wxFILE_SEP_PATH + wxT("configs") + wxFILE_SEP_PATH;
+    config_dir = fityk_dir + wxFILE_SEP_PATH + "configs" + wxFILE_SEP_PATH;
     if (!wxDirExists(config_dir)) {
         wxMkdir(config_dir);
         // create white-background config
@@ -271,20 +262,20 @@ bool FApp::OnInit(void)
     // moving configs from ver. <= 0.9.7 to the current locations
     wxString old_config = get_conf_file("config");
     if (wxFileExists(old_config))
-        wxRenameFile(old_config, config_dir + wxT("default"), false);
+        wxRenameFile(old_config, config_dir + "default", false);
     wxString old_alt_config = get_conf_file("alt-config");
     if (wxFileExists(old_alt_config))
-        wxRenameFile(old_alt_config, config_dir + wxT("alt-config"), false);
+        wxRenameFile(old_alt_config, config_dir + "alt-config", false);
 
     EditTransDlg::read_transforms(false);
 
     // Create the main frame window
-    frame = new FFrame(NULL, -1, wxT("fityk"), wxDEFAULT_FRAME_STYLE);
+    frame = new FFrame(NULL, -1, "fityk", wxDEFAULT_FRAME_STYLE);
 
-    wxString ini_conf = wxT("default");
+    wxString ini_conf = "default";
     // if the -g option was given, it replaces default config
-    cmdLineParser.Found(wxT("g"), &ini_conf);
-    wxConfigBase *cf = new wxFileConfig(wxT(""), wxT(""), config_dir+ini_conf);
+    cmdLineParser.Found("g", &ini_conf);
+    wxConfigBase *cf = new wxFileConfig("", "", config_dir+ini_conf);
     frame->read_all_settings(cf);
 
     frame->Show(true);
@@ -299,7 +290,7 @@ bool FApp::OnInit(void)
 
     SetTopWindow(frame);
 
-    if (!cmdLineParser.Found(wxT("I"))) {
+    if (!cmdLineParser.Found("I")) {
         // run initial commands
         wxString startup_file =
                     get_conf_file(fityk::startup_commands_filename());
@@ -311,7 +302,7 @@ bool FApp::OnInit(void)
     try {
         process_argv(cmdLineParser);
     }
-    catch(fityk::ExitRequestedException) {
+    catch(const fityk::ExitRequestedException&) {
         return false;
     }
 
@@ -323,7 +314,7 @@ bool FApp::OnInit(void)
 int FApp::OnExit()
 {
     delete ftk;
-    wxConfig::Get()->Write(wxT("/FitykVersion"), pchar2wx(VERSION));
+    wxConfig::Get()->Write("/FitykVersion", pchar2wx(VERSION));
     delete wxConfig::Set((wxConfig *) NULL);
     return 0;
 }
@@ -372,13 +363,13 @@ int find_common_prefix_length(vector<string> const& p)
 void FApp::process_argv(wxCmdLineParser &cmdLineParser)
 {
     wxString cmd;
-    if (cmdLineParser.Found(wxT("c"), &cmd))
+    if (cmdLineParser.Found("c", &cmd))
         ftk->ui()->exec_and_log(wx2s(cmd));
     //the rest of parameters/arguments are scripts and/or data files
     vector<string> p;
     for (unsigned int i = 0; i < cmdLineParser.GetParamCount(); i++)
         p.push_back(wx2s(cmdLineParser.GetParam(i)));
-    if (cmdLineParser.Found(wxT("r")) && p.size() > 1) { // reorder
+    if (cmdLineParser.Found("r") && p.size() > 1) { // reorder
         sort(p.begin(), p.end(), less_filename(find_common_prefix_length(p)));
     }
     for (vector<string>::const_iterator i = p.begin(); i != p.end(); ++i) {
@@ -413,42 +404,42 @@ void FApp::process_argv(wxCmdLineParser &cmdLineParser)
 //   {exedir}/../../doc/ and {exedir}/../../../doc/ - for uninstalled program
 wxString get_help_url(const wxString& name)
 {
-    wxString dir = wxFILE_SEP_PATH + wxString(wxT("html"));
+    wxString dir = wxFILE_SEP_PATH + wxString("html");
     wxPathList paths;
     // installed path
 #if defined(__WXMAC__) || defined(__WXMSW__)
     paths.Add(wxStandardPaths::Get().GetResourcesDir() + dir);
 #endif
 #ifdef HELP_DIR
-    paths.Add(wxT(HELP_DIR) + dir);
+    paths.Add(kHelpDir + dir);
 #endif
     // uninstalled paths, relative to executable
-    wxString up = wxFILE_SEP_PATH + wxString(wxT(".."));
+    wxString up = wxFILE_SEP_PATH + wxString("..");
     paths.Add(wxPathOnly(wxGetApp().argv[0]) + up + up
-              + wxFILE_SEP_PATH + wxT("doc") + dir);
+              + wxFILE_SEP_PATH + "doc" + dir);
     paths.Add(wxPathOnly(wxGetApp().argv[0]) + up + up + up
-              + wxFILE_SEP_PATH + wxT("doc") + dir);
+              + wxFILE_SEP_PATH + "doc" + dir);
 
     wxString path = paths.FindAbsoluteValidPath(name);
     if (!path.IsEmpty())
         return wxFileSystem::FileNameToURL(path);
     else
-        return wxT("http://fityk.nieto.pl/") + name;
+        return "http://fityk.nieto.pl/" + name;
 }
 
 wxString get_sample_path(const wxString& name)
 {
-    wxString dir = wxFILE_SEP_PATH + wxString(wxT("samples"));
+    wxString dir = wxFILE_SEP_PATH + wxString("samples");
     wxPathList paths;
     // installed path
 #if defined(__WXMAC__) || defined(__WXMSW__)
     paths.Add(wxStandardPaths::Get().GetResourcesDir() + dir);
 #endif
 #ifdef HELP_DIR
-    paths.Add(wxT(HELP_DIR) + dir);
+    paths.Add(kHelpDir + dir);
 #endif
     // uninstalled paths, relative to executable
-    wxString up = wxFILE_SEP_PATH + wxString(wxT(".."));
+    wxString up = wxFILE_SEP_PATH + wxString("..");
     paths.Add(wxPathOnly(wxGetApp().argv[0]) + up + up + dir);
     paths.Add(wxPathOnly(wxGetApp().argv[0]) + up + up + up + dir);
     wxFileName path(paths.FindAbsoluteValidPath(name));
