@@ -17,6 +17,7 @@
 #include <wx/stdpaths.h>
 #include <wx/clipbrd.h>
 #include <wx/filepicker.h>
+#include <wx/filename.h>
 
 #include <algorithm>
 #include <string.h>
@@ -83,6 +84,7 @@
 #include "img/zoom_right.xpm"
 #include "img/zoom_up.xpm"
 #include "img/zoom_vert.xpm"
+#include "img/log_y_toggle.xpm"
 
 #include "img/book16.h"
 #include "img/editor16.h"
@@ -129,8 +131,8 @@ static const wxString website_url(
         wxT("http://fityk.nieto.pl/"));
 static const wxString wiki_url(
         wxT("https://github.com/wojdyr/fityk/wiki"));
-static const wxString feedback_url(
-        wxT("http://fityk.nieto.pl/feedback/") + pchar2wx(VERSION));
+static const wxString issues_url(
+        wxT("http://github.com/wojdyr/fityk/issues"));
 
 enum {
     // menu
@@ -138,7 +140,7 @@ enum {
     ID_H_WEBSITE               ,
     ID_H_WIKI                  ,
     ID_H_DISCUSSIONS           ,
-    ID_H_FEEDBACK              ,
+    ID_H_ISSUES                ,
     ID_H_EXAMPLE1              ,
     ID_H_EXAMPLE2              ,
     ID_H_EXAMPLE3              ,
@@ -254,6 +256,7 @@ enum {
     ID_T_RUN                  ,
     ID_T_UNDO                 ,
     ID_T_AUTO                 ,
+    ID_T_LOGY                 ,
     //ID_T_BAR                  ,
     ID_T_CHOICE
 };
@@ -381,7 +384,7 @@ BEGIN_EVENT_TABLE(FFrame, wxFrame)
     EVT_MENU (ID_H_WEBSITE,     FFrame::OnOnline)
     EVT_MENU (ID_H_WIKI,        FFrame::OnOnline)
     EVT_MENU (ID_H_DISCUSSIONS, FFrame::OnOnline)
-    EVT_MENU (ID_H_FEEDBACK,    FFrame::OnOnline)
+    EVT_MENU (ID_H_ISSUES,      FFrame::OnOnline)
     EVT_MENU_RANGE (ID_H_EXAMPLE1, ID_H_EXAMPLE4, FFrame::OnExample)
     EVT_MENU (wxID_ABOUT,       FFrame::OnAbout)
     EVT_MENU (wxID_EXIT,        FFrame::OnQuit)
@@ -407,8 +410,10 @@ FFrame::FFrame(wxWindow *parent, const wxWindowID id, const wxString& title,
 
     //sizer, splitters, etc.
     wxBoxSizer *sizer = new wxBoxSizer(wxVERTICAL);
-    v_splitter_ = new ProportionalSplitter(this);
-    main_pane_ = new ProportionalSplitter(v_splitter_);
+    v_splitter_ = new ProportionalSplitter(this, -1, 0.66, wxDefaultSize,
+                                           wxSP_3DSASH);
+    main_pane_ = new ProportionalSplitter(v_splitter_, -1, 0.66, wxDefaultSize,
+                                          wxSP_3DSASH);
     plot_pane_ = new PlotPane(main_pane_);
     text_pane_ = new TextPane(main_pane_);
     main_pane_->SplitHorizProp(plot_pane_, text_pane_);
@@ -805,10 +810,8 @@ void FFrame::set_menubar()
               wiki_url);
     append_mi(help_menu, ID_H_DISCUSSIONS, GET_BMP(web16),
               wxT("&Visit Discussions"), discussions_url);
-    /*
-    append_mi(help_menu, ID_H_FEEDBACK, GET_BMP(web16),
-              wxT("&Anonymous Feedback"), feedback_url);
-    */
+    append_mi(help_menu, ID_H_ISSUES, GET_BMP(web16),
+              wxT("&Visit Issues"), issues_url);
     wxMenu* help_menu_examples = new wxMenu;
     help_menu_examples->Append(ID_H_EXAMPLE1, wxT("&Single Peak"),
                                wxT("nacl01.fit"));
@@ -907,8 +910,8 @@ void FFrame::OnOnline(wxCommandEvent& event)
         url = &wiki_url;
     else if (event.GetId() == ID_H_DISCUSSIONS)
         url = &discussions_url;
-    else //if (event.GetId() == ID_H_FEEDBACK)
-        url = &feedback_url;
+    else //if (event.GetId() == ID_H_ISSUES)
+        url = &issues_url;
     bool r = wxLaunchDefaultBrowser(*url);
     if (!r)
         wxMessageBox(wxT("Can not open URL in browser,")
@@ -965,17 +968,18 @@ void FFrame::OnDataQLoad (wxCommandEvent&)
         return;
 
     string cmd;
-    string options;
+    std::string tail;
     wxWindow *extra = fdlg.GetExtraControl();
+    bool decimal_comma = false;
     if (extra != NULL) {
         Extra2CheckBoxes *extracb = wxDynamicCast(extra,Extra2CheckBoxes);
         string selected = extracb->is_checked1() ? "sqrt" : "one";
         if (ftk->get_settings()->default_sigma != selected)
             cmd = "with default_sigma=" + selected + " ";
 
-        bool decimal_comma = extracb->is_checked2();
+        decimal_comma = extracb->is_checked2();
         if (decimal_comma)
-            options += "decimal_comma";
+            tail = "_ decimal_comma";
         wxConfig::Get()->Write("decimalComma", decimal_comma);
     }
 
@@ -1032,14 +1036,13 @@ void FFrame::OnDataQLoad (wxCommandEvent&)
                 cmd += "lua ";
             }
         if (has_single_quote) { // very special case
-            cmd += "F:load(-1, [[" + wx2s(paths[i]) + "]], 0, 1, 2, 0, '', '"
-                + options + "')";
+            int NN = fityk::LoadSpec::NN;
+            cmd += make_lua_load(-1, paths[i], 0, NN, NN, NN,
+                                 "", decimal_comma);
         } else {
-            cmd += "@+ <'" + wx2s(paths[i]) + "'";
-            if (!options.empty())
-               cmd += " _ " + options;
+            cmd += "@+ <'" + wx2s(paths[i]) + "' " + tail;
         }
-        recent_data_->add(paths[i], options.empty() ? "" : "_ "+options);
+        recent_data_->add(paths[i], tail);
     }
 
     exec(cmd);
@@ -1476,15 +1479,26 @@ void FFrame::show_editor(const wxString& path, const wxString& content)
     dlg->Show(true);
 }
 
+static void split_path(const wxString& path, wxString* dir, wxString* name) {
+    if (path.empty())
+        return;
+    wxFileName fn(path);
+    *dir = fn.GetPath(); // GetPath() returns only directory not path
+    *name = fn.GetFullName(); // "fullname" is basename w/ extension
+}
+
 void FFrame::OnSessionLoad(wxCommandEvent&)
 {
+    wxString dir = script_dir_;
+    wxString file;
+    split_path(last_session_path_, &dir, &file);
     wxFileDialog fdlg(this, "Run script (after resetting session)",
-                      script_dir_, "", fityk_lua_wildcards,
+                      dir, file, fityk_lua_wildcards,
                       wxFD_OPEN | wxFD_FILE_MUST_EXIST);
     if (fdlg.ShowModal() == wxID_OK) {
         get_main_plot()->bgm()->clear_background();
-        exec("reset; exec '" + wx2s(fdlg.GetPath()) + "'");
-        //last_include_path_ = wx2s(fdlg.GetPath());
+        last_session_path_ = fdlg.GetPath();
+        exec("reset; exec '" + wx2s(last_session_path_) + "'");
         //GetMenuBar()->Enable(ID_SESSION_RECENT, true);
     }
     script_dir_ = fdlg.GetDirectory();
@@ -1492,14 +1506,17 @@ void FFrame::OnSessionLoad(wxCommandEvent&)
 
 void FFrame::OnSessionSave(wxCommandEvent&)
 {
-    wxFileDialog fdlg(this, wxT("Save everything as a script"),
-                      export_dir_, wxT(""),
-                      wxT("fityk file (*.fit)|*.fit;*.FIT"),
+    wxString dir = script_dir_;
+    wxString file;
+    split_path(last_session_path_, &dir, &file);
+    wxFileDialog fdlg(this, "Save everything as a script",
+                      dir, file, "fityk file (*.fit)|*.fit;*.FIT",
                       wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
     if (fdlg.ShowModal() == wxID_OK) {
-        exec("info state > '" + wx2s(fdlg.GetPath()) + "'");
+        last_session_path_ = fdlg.GetPath();
+        exec("info state > '" + wx2s(last_session_path_) + "'");
     }
-    export_dir_ = fdlg.GetDirectory();
+    script_dir_ = fdlg.GetDirectory();
 }
 
 void FFrame::OnSettings (wxCommandEvent&)
@@ -1736,17 +1753,17 @@ void FFrame::OnConfigureDirectories(wxCommandEvent&)
     wxDirPickerCtrl *dp = new wxDirPickerCtrl(&dlg, -1, data_dir_,
                 wxDirSelectorPromptStr, wxDefaultPosition, wxDefaultSize,
                 wxDIRP_USE_TEXTCTRL);
-    gsizer->Add(dp, wxSizerFlags().Center().Expand());
+    gsizer->Add(dp, wxSizerFlags().Expand());
     gsizer->Add(new wxStaticText(&dlg, -1, "Script Directory"), sf);
     wxDirPickerCtrl *sp = new wxDirPickerCtrl(&dlg, -1, script_dir_,
                 wxDirSelectorPromptStr, wxDefaultPosition, wxDefaultSize,
                 wxDIRP_USE_TEXTCTRL);
-    gsizer->Add(sp, wxSizerFlags().Center().Expand());
+    gsizer->Add(sp, wxSizerFlags().Expand());
     gsizer->Add(new wxStaticText(&dlg, -1, "Export Directory"), sf);
     wxDirPickerCtrl *ep = new wxDirPickerCtrl(&dlg, -1, export_dir_,
                 wxDirSelectorPromptStr, wxDefaultPosition, wxDefaultSize,
                 wxDIRP_USE_TEXTCTRL);
-    gsizer->Add(ep, wxSizerFlags().Center().Expand());
+    gsizer->Add(ep, wxSizerFlags().Expand());
     top_sizer->Add(gsizer, wxSizerFlags().Border().Expand());
 
     wxBoxSizer *button_sizer = new wxBoxSizer(wxHORIZONTAL);
@@ -2002,11 +2019,11 @@ public:
         c.Border(wxBOTTOM);
 #endif
         sizer->Add(new wxStaticText(this, -1, "width:"), c);
-        w_spin = new SpinCtrl(this, -1, size.x, 0, 9999, 70);
+        w_spin = make_wxspinctrl(this, -1, size.x, 0, 9999, 70);
         sizer->Add(w_spin, c);
         sizer->AddSpacer(10);
         sizer->Add(new wxStaticText(this, -1, "height:"), c);
-        h_spin = new SpinCtrl(this, -1, size.y, 0, 9999, 70);
+        h_spin = make_wxspinctrl(this, -1, size.y, 0, 9999, 70);
         sizer->Add(h_spin, c);
         sizer->AddSpacer(10);
         aux_cb = new wxCheckBox(this, -1, "with auxiliary plots");
@@ -2276,6 +2293,7 @@ BEGIN_EVENT_TABLE (FToolBar, wxToolBar)
     //EVT_TOOL (ID_T_BAR, FToolBar::OnSwitchSideBar)
     EVT_CHOICE (ID_T_CHOICE, FToolBar::OnPeakChoice)
     EVT_TOOL_ENTER (-1, FToolBar::OnToolEnter)
+    EVT_TOOL (ID_T_LOGY, FToolBar::OnLogYToggle)
 END_EVENT_TABLE()
 
 FToolBar::FToolBar (wxFrame *parent, wxWindowID id)
@@ -2327,6 +2345,10 @@ FToolBar::FToolBar (wxFrame *parent, wxWindowID id)
             wxITEM_NORMAL, wxT("Previous view"),
             wxT("Go to the previous view"));
     AddSeparator();
+    AddTool(ID_T_LOGY, wxT("Log y"), wxBitmap(log_y_toggle_xpm), wxNullBitmap,
+            wxITEM_NORMAL, wxT("Toggle y log"),
+            wxT("Toggle y scale between logarithmic and linear"));
+    AddSeparator();
     //file
     AddTool(ID_SESSION_INCLUDE, wxT("Execute"),
             wxBitmap(run_script_xpm), wxNullBitmap, wxITEM_NORMAL,
@@ -2449,6 +2471,18 @@ void FToolBar::OnToolEnter(wxCommandEvent& event)
     }
 }
 
+void FToolBar::OnLogYToggle(wxCommandEvent&)
+{
+    const bool log_x = frame->get_main_plot()->get_x_scale().logarithm;
+    const bool log_y = frame->get_main_plot()->get_y_scale().logarithm;
+
+    frame->get_main_plot()->get_x_scale().logarithm = log_x;
+    frame->get_main_plot()->get_y_scale().logarithm = !log_y;
+    ftk->view.set_log_scale(log_x, !log_y);
+
+    frame->plot_pane()->refresh_plots(false, kMainPlot);
+}
+
 void FToolBar::on_addpeak_hover()
 {
     string info;
